==> eh-0.4.tar.gz: eh-0.4/src/t_filtrk.c <==
/***

t_filtrk.c -- test driver for file usage tracking routines

***/

#include <string.h>

#include "eh.h"
#include "ehfiltrk.h"

static void fopen_and_fclose();
static void fopen_and_no_fclose();
static void tmpfile_and_fclose();
static void tmpfile_and_no_fclose();
static void fopen_freopen_and_fclose();
static void fopen_freopen_and_no_fclose();
static void freopen_stdin_and_fclose();
static void freopen_stdin_and_no_fclose();
static void freopen_stdout_and_no_fclose();
static void freopen_stderr_and_no_fclose();

int
main(int argc, char**argv)
{
   EHMAIN(argc, argv) {

      fopen_and_fclose();
      fopen_and_no_fclose();

      tmpfile_and_fclose();
      tmpfile_and_no_fclose();

      fopen_freopen_and_fclose();
      fopen_freopen_and_no_fclose();

      freopen_stdin_and_fclose();
      freopen_stdin_and_no_fclose();

   } EHENDMAIN;

   EHMAINRETURN(ehError());
}


static
void
fopen_and_fclose()
{
   FILE*volatile pFile = NULL;

   EHCATCH(fopen_and_fclose) {

      pFile = fopen("t_filtrk.1", "w");

   } EHENDCATCH;

   if (pFile) fclose(pFile);
}


static
void
fopen_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(fopen_and_no_close);
   pFile = fopen("t_filtrk.2", "w");
}


static
void
tmpfile_and_fclose()
{
   FILE*volatile pFile = NULL;

   EHCATCH(tmpfile_and_fclose) {

      pFile = tmpfile();

   } EHENDCATCH;

   if (pFile) fclose(pFile);
}


static
void
tmpfile_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(tmpfile_and_no_close);
   pFile = tmpfile();
}


static
void
fopen_freopen_and_fclose()
{
   FILE *volatile pFile = NULL;

   EHCATCH(fopen_freopen_and_fclose) {

      pFile = fopen("t_filtrk.3", "w");
      pFile = freopen("t_filtrk.4", "w", pFile);

   } EHENDCATCH;

   if (pFile) fclose(pFile);
}


static
void
fopen_freopen_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(fopen_freopen_and_no_fclose);
   pFile = fopen("t_filtrk.5", "w");
   pFile = freopen("t_filtrk.6", "w", pFile);
}


static
void
freopen_stdin_and_fclose()
{
   FILE *volatile pFile = NULL;

   EHCATCH(freopen_stdin_and_fclose) {

      pFile = freopen("t_filtrk.7", "w", stdin);

   } EHENDCATCH;

   if (pFile) fclose(pFile);
}


static
void
freopen_stdin_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(freopen_stdin_and_no_fclose);
   pFile = freopen("t_filtrk.8", "w", stdin);
}


static
void
freopen_stdout_and_fclose()
{
   FILE *volatile pFile = NULL;

   EHCATCH(freopen_stdout_and_fclose) {

      pFile = freopen("t_filtrk.9", "w", stdout);

   } EHENDCATCH;

   if (pFile) fclose(pFile);
}


static
void
freopen_stdout_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(freopen_stdout_and_no_fclose);
   pFile = freopen("t_filtrk.10", "w", stdout);
}


static
void
freopen_stderr_and_fclose()
{
   FILE *volatile pFile = NULL;

   EHCATCH(freopen_stderr_and_fclose) {

      pFile = freopen("t_filtrk.11", "w", stderr);

   } EHENDCATCH;

   if (pFile) fclose(pFile);
}


static
void
freopen_stderr_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(freopen_stderr_and_no_fclose);
   pFile = freopen("t_filtrk.12", "w", stderr);
}

==> eh-0.5.tar.gz: eh-0.5/src/t_filtrk.c <==
/***

t_filtrk.c -- test driver for file usage tracking routines

    Copyright (C) 1997  CSEG, Inc., All rights reserved.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.                   

    The GNU General Public License is in the file COPYING which resides
    in the top directory of the distribution tree.

***/

#include <string.h>

#include "eh.h"
#include "ehfiltrk.h"

static void fopen_and_fclose();
static void fopen_and_no_fclose();
static void tmpfile_and_fclose();
static void tmpfile_and_no_fclose();
static void fopen_freopen_and_fclose();
static void fopen_freopen_and_no_fclose();
static void freopen_stdin_and_fclose();
static void freopen_stdin_and_no_fclose();
static void freopen_stdout_and_no_fclose();
static void freopen_stderr_and_no_fclose();

int
main(int argc, char**argv)
{
   EHMAIN(argc, argv) {

      fopen_and_fclose();
      fopen_and_no_fclose();

      tmpfile_and_fclose();
      tmpfile_and_no_fclose();

      fopen_freopen_and_fclose();
      fopen_freopen_and_no_fclose();

      freopen_stdin_and_fclose();
      freopen_stdin_and_no_fclose();

   } EHENDMAIN;

   EHDONE(ehError());
}


static
void
fopen_and_fclose()
{
   FILE*volatile pFile = NULL;

   EHTRY(fopen_and_fclose) {

      pFile = fopen("t_filtrk.1", "w");

   } EHCATCH;

   if (pFile) fclose(pFile);
}


static
void
fopen_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(fopen_and_no_fclose);
   pFile = fopen("t_filtrk.2", "w");
}


static
void
tmpfile_and_fclose()
{
   FILE*volatile pFile = NULL;

   EHTRY(tmpfile_and_fclose) {

      pFile = tmpfile();

   } EHCATCH;

   if (pFile) fclose(pFile);
}


static
void
tmpfile_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(tmpfile_and_no_fclose);
   pFile = tmpfile();
}


static
void
fopen_freopen_and_fclose()
{
   FILE *volatile pFile = NULL;

   EHTRY(fopen_freopen_and_fclose) {

      pFile = fopen("t_filtrk.3", "w");
      pFile = freopen("t_filtrk.4", "w", pFile);

   } EHCATCH;

   if (pFile) fclose(pFile);
}


static
void
fopen_freopen_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(fopen_freopen_and_no_fclose);
   pFile = fopen("t_filtrk.5", "w");
   pFile = freopen("t_filtrk.6", "w", pFile);
}


static
void
freopen_stdin_and_fclose()
{
   FILE *volatile pFile = NULL;

   EHTRY(freopen_stdin_and_fclose) {

      pFile = freopen("t_filtrk.7", "w", stdin);

   } EHCATCH;

   if (pFile) fclose(pFile);
}


static
void
freopen_stdin_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(freopen_stdin_and_no_fclose);
   pFile = freopen("t_filtrk.8", "w", stdin);
}


static
void
freopen_stdout_and_fclose()
{
   FILE *volatile pFile = NULL;

   EHTRY(freopen_stdout_and_fclose) {

      pFile = freopen("t_filtrk.9", "w", stdout);

   } EHCATCH;

   if (pFile) fclose(pFile);
}


static
void
freopen_stdout_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(freopen_stdout_and_no_fclose);
   pFile = freopen("t_filtrk.10", "w", stdout);
}


static
void
freopen_stderr_and_fclose()
{
   FILE *volatile pFile = NULL;

   EHTRY(freopen_stderr_and_fclose) {

      pFile = freopen("t_filtrk.11", "w", stderr);

   } EHCATCH;

   if (pFile) fclose(pFile);
}


static
void
freopen_stderr_and_no_fclose()
{
   FILE *pFile = NULL;
   EHTRACE(freopen_stderr_and_no_fclose);
   pFile = freopen("t_filtrk.12", "w", stderr);
}
